@@ -4,17 +4,17 @@ use strict;
 use warnings;
 
 use Exporter;
-our $VERSION	= 0.15;
+our $VERSION	= 0.8031;
 our @ISA	= qw(Exporter);
 our @EXPORT_OK	= qw(
-			EDMS_edidx_build 
+			EDMS_edidx_build
 			EDMS_edidx_write
 			EDMS_idldoc_seqpg
 			EDMS_idx_create_csv
-			EDMS_import 
-			EDMS_prepare 
-			EDMS_process 
-			EDMS_process_zip 
+			EDMS_import
+			EDMS_prepare
+			EDMS_process
+			EDMS_process_zip
 		);
 
 # use File::Temp	qw(tempdir);
@@ -44,12 +44,12 @@ sub EDMS_idldoc_seqpg($$) {
 
 # Package a PDF along with its index in a zip archive for later processing.
 sub EDMS_prepare($$$$) {
-	my ($app, $idldoc, $pdfpath, $idxpath) = @_;
+	my ($app, $idldoc, $doc_path, $idx_path) = @_;
 
 	my $cfg = config_read('EDOCMNGR');
 	my $zip = Archive::Zip->new();
-	$zip->addFile($pdfpath, "$app.$idldoc.pdf");
-	$zip->addFile($idxpath, basename($idxpath));
+	$zip->addFile($doc_path, "$app.$idldoc.pdf");
+	$zip->addFile($idx_path, basename($idx_path));
 
 	my $zipfile = "$cfg->{'EDTK_DIR_EDOCMNGR'}/$app.$idldoc.out.zip";
 	die "ERROR: Could not create zip achive \"$zipfile\"\n"
@@ -59,6 +59,7 @@ sub EDMS_prepare($$$$) {
 return 1;
 }
 
+
 sub EDMS_process_zip($;$) {
 	my ($zipfile, $outdir) = @_;
 
@@ -67,43 +68,53 @@ sub EDMS_process_zip($;$) {
 		die "ERROR: Unexpected zip filename: $zipname\n";
 	}
 	my ($app, $idldoc) = ($1, $2);
-	
+
 	my $zip = Archive::Zip->new();
 	if ($zip->read($zipfile) != AZ_OK) {
 		die "ERROR: Could not read zip archive \"$zipfile\"\n";
 	}
 
 	my @files = $zip->members();
-	my ($pdfmember) = $zip->membersMatching('\.pdf$');
-	my ($idxmember) = $zip->membersMatching('\.idx1$');
-	if (!defined($pdfmember) || !defined($idxmember)) {
-		die "ERROR: Could not find PDF or index file in archive\n";
+	my ($idx_member) = $zip->membersMatching('\.idx1$');
+	my ($doc_member) = $zip->membersMatching('\.pdf$');
+		if (!defined($doc_member)){
+			($doc_member) = $zip->membersMatching('\.xls$');
+		}
+		if (!defined($doc_member)){
+			($doc_member) = $zip->membersMatching('\.doc$');
+		}
+	if (!defined($doc_member) || !defined($idx_member)) {
+		die "ERROR: Could not find document(s) or index file in archive\n";
 	}
-	my $pdfname = $pdfmember->fileName();
-	my $idxname = $idxmember->fileName();
-	my $pdfpath = $pdfname;
-	my $idxpath = $idxname;
+	my $doc_name = $doc_member->fileName();
+	my $idx_name = $idx_member->fileName();
+	my $doc_path = $doc_name;
+	my $idx_path = $idx_name;
 	if (defined($outdir)) {
-		$pdfpath = "$outdir/$pdfpath";
-		$idxpath = "$outdir/$idxpath";
+		$doc_path = "$outdir/$doc_path";
+		$idx_path = "$outdir/$idx_path";
 	}
-	warn "INFO : Extracting file \"$pdfname\"\n";
-	if ($zip->extractMember($pdfmember, $pdfpath) != AZ_OK) {
-		die "ERROR: Could not extract \"$pdfname\" from archive\n";
+	warn "INFO : Extracting file \"$doc_name\"\n";
+	if ($zip->extractMember($doc_member, $doc_path) != AZ_OK) {
+		die "ERROR: Could not extract \"$doc_name\" from archive\n";
 	}
-	warn "INFO : Extracting file \"$idxname\"\n";
-	if ($zip->extractMember($idxmember, $idxpath) != AZ_OK) {
-		die "ERROR: Could not extract \"$idxname\" from archive\n";
+	warn "INFO : Extracting file \"$idx_name\"\n";
+	if ($zip->extractMember($idx_member, $idx_path) != AZ_OK) {
+		die "ERROR: Could not extract \"$idx_name\" from archive\n";
 	}
 
-	return EDMS_process($app, $idldoc, $pdfname, $idxname, $outdir);
+return EDMS_process($app, $idldoc, $doc_name, $idx_name, $outdir);
 }
 
-# Process a PDF document with its index in a way suitable for the edms software.
-sub EDMS_process($$$$;$) {
-	my ($app, $idldoc, $pdf, $index, $outdir) = @_;
 
-	my $cfg = config_read('EDOCMNGR'); 
+# Process document(s) with its index in a way suitable for the edms software.
+sub EDMS_process($$$$;$) {
+	my ($app, $idldoc, $doc, $index, $outdir) = @_;
+	# Remplace les - et les . par des _ car Docubase ne peut pas importer de fichier comprenant des . dans leur nom
+	$idldoc	=~ s/[-\.]/_/g;
+	$app		=~ s/[-\.]/_/g;
+
+	my $cfg = config_read('EDOCMNGR');
 	my $format  = $cfg->{'EDMS_IDX_FORMAT'};
 	my @edmscols = split(/,/, $cfg->{'EDMS_INDEX_COLS'});
 
@@ -113,34 +124,38 @@ sub EDMS_process($$$$;$) {
 		chdir($outdir)
 		    or die "ERROR: Cannot change current directory to \"$outdir\": $!\n";
 	}
-
 	my @outfiles = ();
-	warn "INFO : Splitting $pdf into individual docs...\n";
 
-	# Remplace les - et les . par des _ car Docubase ne peut pas importer de fichier comprenant des . dans leur nom
-	$idldoc =~ s/[-\.]/_/g;
-	$app =~ s/[-\.]/_/g;
+	if ($doc =~ /pdf$/i){
+		warn "INFO : Splitting $doc into individual docs...\n";
 
-	## gs -sDEVICE=pdfwrite \
-	##   -q -dNOPAUSE -dBATCH \
-	##   -sOutputFile=sample-1.pdf \
-	##   -dFirstPage=1 \
-	##   -dLastPage=1 \
-	##   FAX200904010240-1.PDF
-	#my $this_pdf = PDF->new;
-	#$this_pdf = PDF->new($pdf);
+		## gs -sDEVICE=pdfwrite \
+		##   -q -dNOPAUSE -dBATCH \
+		##   -sOutputFile=sample-1.pdf \
+		##   -dFirstPage=1 \
+		##   -dLastPage=1 \
+		##   FAX200904010240-1.PDF
+		#my $this_pdf = PDF->new;
+		#$this_pdf = PDF->new($doc);
 
-	#my $output = "${app}_${idldoc}_%07d.pdf";
-	#my $gs = system ($cfg->{'EDMS_BIN_GS'} . " -q -dNOPAUSE -dBATCH -sDEVICE=pdfwrite -dFirstPage=1 -dLastPage=". $this_pdf->Pages ." -sOutputFile=$output $pdf ");
-	#if ($gs != 0) {
-	#	die "ERROR: Could not split pages from $pdf to $output !\n";
-	#}
+		#my $output = "${app}_${idldoc}_%07d.pdf";
+		#my $gs = system ($cfg->{'EDMS_BIN_GS'} . " -q -dNOPAUSE -dBATCH -sDEVICE=pdfwrite -dFirstPage=1 -dLastPage=". $this_pdf->Pages ." -sOutputFile=$output $doc ");
+		#if ($gs != 0) {
+		#	die "ERROR: Could not split pages from $doc to $output !\n";
+		#}
 
-	# Modifi suite au problme des points dans les noms de fichiers pour docubase
-	my $rv = system($cfg->{'EDMS_BIN_PDFTK'} . " $pdf burst output ${app}_${idldoc}_%07d.pdf ");
-	
-	if ($rv != 0) {
-		die "ERROR: Could not burst PDF file $pdf!\n";
+		# Modifi suite au problme des points dans les noms de fichiers pour docubase
+		my $rv = system($cfg->{'EDMS_BIN_PDFTK'} . " $doc burst output ${app}_${idldoc}_%07d.pdf ");
+
+		if ($rv != 0) {
+			die "ERROR: Could not burst PDF file $doc!\n";
+		}
+
+	} else {
+		#warn "DEBUG: document $doc is not pdf file\n";
+		my $cible = _docubase_file_name($doc);
+		move ($doc, $cible) or die "ERROR: echec move $cible ($doc)\n";
+		push (@outfiles, $cible);
 	}
 
 	if ($format eq 'DOCUBASE') {
@@ -152,7 +167,7 @@ sub EDMS_process($$$$;$) {
 	}
 
 	if ($cfg->{'EDTK_TYPE_ENV'} ne 'Test') {
-		unlink($pdf);
+		unlink($doc) if ($doc =~ /pdf$/i);
 		unlink($index);
 		unlink('doc_data.txt');		# pdftk creates this one.
 	}
@@ -161,7 +176,8 @@ sub EDMS_process($$$$;$) {
 		# Restore original working directory.
 		chdir($oldcwd);
 	}
-	return @outfiles;
+
+return @outfiles;
 }
 
 
@@ -189,7 +205,7 @@ sub EDMS_import($@) {
 	}
 	warn "INFO : Uploading index file $index\n";
 	$ftp->cwd()
-	    or die "ERROR: Cannot change working directory : " . $ftp->message() . "\n";	
+	    or die "ERROR: Cannot change working directory : " . $ftp->message() . "\n";
 	$ftp->cwd($cfg->{'EDMS_FTP_DIR_IDX'})
 	    or die "ERROR: Cannot change working directory : " . $ftp->message() . "\n";
 	$ftp->put($index)
@@ -225,6 +241,7 @@ sub EDMS_idx_process($$$$&) {
 			foreach (@$keys) {
 				$docvals{$_} = $vals->{$_};
 			}
+			$docvals{'ED_DOCLIB'} = $vals->{'ED_DOCLIB'};
 			$firstpg = $vals->{'ED_IDSEQPG'};
 			$numpgs  = 1;
 
@@ -233,6 +250,7 @@ sub EDMS_idx_process($$$$&) {
 			foreach (@$keys) {
 				$docvals{$_} = $vals->{$_} if $vals->{$_};
 			}
+			$docvals{'ED_DOCLIB'} = $vals->{'ED_DOCLIB'};
 			$numpgs++;
 		}
 	}
@@ -245,6 +263,19 @@ sub EDMS_idx_process($$$$&) {
 	close($fh);
 }
 
+
+sub _docubase_file_name($){
+	my $filename = shift;
+
+	$filename =~s/(^.*)(\.\w{2,4}$)/$1/;
+	my $ext	= $2 || "";
+	$filename =~s/[-\.]/_/g;
+	$filename .= $ext;
+
+return $filename;
+}
+
+
 # CREATE A EDMS INDEX FILE IN CSV FORMAT (FOR EDMS APPLICATION).
 sub EDMS_idx_create_csv($$$$$) {
 	my ($cfg, $idx, $app, $idldoc, $keys) = @_;
@@ -259,8 +290,12 @@ sub EDMS_idx_create_csv($$$$$) {
 	EDMS_idx_process($app, $idx, $idldoc, $keys, sub {
 		my ($vals, $firstpg, $numpgs) = @_;
 
-		$vals->{'EDMS_IDLDOC_SEQPG'} = EDMS_idldoc_seqpg($idldoc, $firstpg);
-		$vals->{'EDMS_FILENAME'}  = "${app}_". $vals->{'EDMS_IDLDOC_SEQPG'} .".pdf";
+		if ($vals->{'ED_DOCLIB'} =~ /pdf$/i) {
+			$vals->{'EDMS_IDLDOC_SEQPG'} = EDMS_idldoc_seqpg($idldoc, $firstpg);
+			$vals->{'EDMS_FILENAME'}  = "${app}_". $vals->{'EDMS_IDLDOC_SEQPG'} .".pdf";
+		} else {
+			$vals->{'EDMS_FILENAME'}  = _docubase_file_name($vals->{'ED_DOCLIB'});
+		}
 
 		# Dates need to be in a specific format.
 		my $datefmt = $cfg->{'EDMS_DATE_FORMAT'};
@@ -297,6 +332,8 @@ sub EDMS_idx_create_xml($$$$$) {
 
 		my $docid = EDMS_idldoc_seqpg($idldoc, $firstpg);
 		my $xmlfile = "$docid.edms.xml";
+		$vals->{'ED_DOCLIB'} =~ /\.(\w{2,4})$/;
+		my $ext = $1;
 
 		open(my $fh, '>', $xmlfile) or die "ERROR: Cannot create \"$xmlfile\": $!\n";
 		my $xml = XML::Writer->new(OUTPUT => $fh, ENCODING => 'utf-8');
@@ -317,7 +354,7 @@ sub EDMS_idx_create_xml($$$$$) {
 		close($fh);
 
 		push(@outfiles, $xmlfile);
-		push(@outfiles, "${app}_$docid.pdf");
+		push(@outfiles, "${app}_$docid.$ext");
 	});
 	return @outfiles;
 }
@@ -363,30 +400,30 @@ sub EDMS_edidx_build (\%){
 
 # EDMS_INDEX_COLS		=ED_REFIDDOC,ED_CORP,ED_SOURCE,EDMS_IDLDOC_SEQPG,ED_DTEDTION,ED_CLEGED1,ED_IDDEST,ED_NOMDEST,ED_VILLDEST,ED_IDEMET,ED_CLEGED2,ED_CLEGED3,ED_CLEGED4,ED_OWNER,EDMS_FILENAME
 # clefs d'index requises 	: ED_REFIDDOC, ED_CORP, ED_SOURCE, ED_IDDEST, ED_NOMDEST, ED_IDEMET, ED_OWNER, ED_CORP
-# clefs optionnelles		: ED_DTEDTION, ED_CLEGED1, ED_VILLDEST, ED_CLEGED2, ED_CLEGED3, ED_CLEGED4 
+# clefs optionnelles		: ED_DTEDTION, ED_CLEGED1, ED_VILLDEST, ED_CLEGED2, ED_CLEGED3, ED_CLEGED4
 # clefs (re)calcules		: ED_DTEDTION, EDMS_IDLDOC_SEQPG, EDMS_FILENAME
 
 	# REQUIRED KEYS
 	if (!defined $$refOpt{'ED_REFIDDOC'} or $$refOpt{'ED_REFIDDOC'} eq ""){
-		die "ERROR: ED_REFIDDOC required.\n";	
+		die "ERROR: ED_REFIDDOC required.\n";
 	}
 	if (!defined $$refOpt{'ED_SOURCE'} or $$refOpt{'ED_SOURCE'} eq ""){
-		die "ERROR: ED_SOURCE required.\n";	
+		die "ERROR: ED_SOURCE required.\n";
 	}
 	if (!defined $$refOpt{'ED_IDDEST'} or $$refOpt{'ED_IDDEST'} eq ""){
-		die "ERROR: ED_IDDEST required.\n";	
+		die "ERROR: ED_IDDEST required.\n";
 	}
 	if (!defined $$refOpt{'ED_NOMDEST'} or $$refOpt{'ED_NOMDEST'} eq ""){
-		die "ERROR: ED_NOMDEST required.\n";	
+		die "ERROR: ED_NOMDEST required.\n";
 	}
 	if (!defined $$refOpt{'ED_IDEMET'} or $$refOpt{'ED_IDEMET'} eq ""){
-		die "ERROR: ED_IDEMET required.\n";	
+		die "ERROR: ED_IDEMET required.\n";
 	}
 	if (!defined $$refOpt{'ED_OWNER'} or $$refOpt{'ED_OWNER'} eq ""){
-		die "ERROR: ED_OWNER required.\n";	
+		die "ERROR: ED_OWNER required.\n";
 	}
 	if (!defined $$refOpt{'ED_CORP'} or $$refOpt{'ED_CORP'} eq ""){
-		die "ERROR: ED_CORP required.\n";	
+		die "ERROR: ED_CORP required.\n";
 	}
 
 
@@ -398,7 +435,7 @@ sub EDMS_edidx_build (\%){
 	my ($sec,$min,$hour,$day,$month,$year);
 	if (!defined $$refOpt{'ED_DTEDTION'} || $$refOpt{'ED_DTEDTION'} !~ /^(\d{4})(\d{2})(\d{2})$/) {
 		#die "ERROR: Unexpected date format for ED_DTEDTION: $$refOpt{'ED_DTEDTION'}\n";
-		($sec,$min,$hour,$day,$month,$year) = localtime(); 
+		($sec,$min,$hour,$day,$month,$year) = localtime();
 		$month ++;
 		$year += 1900;
 	} else {
@@ -406,10 +443,10 @@ sub EDMS_edidx_build (\%){
 	}
 
 	# DATES NEED TO BE IN A SPECIFIC FORMAT.
-	my $datefmt = $cfg->{'EDMS_DATE_FORMAT'}; 
+	my $datefmt = $cfg->{'EDMS_DATE_FORMAT'};
 	$$refOpt{'ED_DTEDTION'}		= strftime($datefmt, 0, 0, 0, $day, $month - 1, $year - 1900);
 	$$refOpt{'ED_IDLDOC'}		= oEdtk::Main::oe_ID_LDOC();
-	$$refOpt{'ED_IDSEQPG'}		= 1;	
+	$$refOpt{'ED_IDSEQPG'}		= 1;
 	$$refOpt{'ED_SEQDOC'}		= 1;
 	$$refOpt{'EDMS_IDLDOC_SEQPG'} 	= EDMS_idldoc_seqpg($$refOpt{'ED_IDLDOC'}, $$refOpt{'ED_IDSEQPG'});
 	$$refOpt{'EDMS_FILENAME'} 	= $$refOpt{'ED_REFIDDOC'} . "_" .$$refOpt{'EDMS_IDLDOC_SEQPG'};
@@ -420,7 +457,7 @@ sub EDMS_edidx_build (\%){
 	# OPTIONNAL KEYS
 	$$refOpt{'ED_VILLDEST'}|= "";
 	$$refOpt{'ED_CLEGED1'} |= "";
-	$$refOpt{'ED_CLEGED2'} |= "";	
+	$$refOpt{'ED_CLEGED2'} |= "";
 	$$refOpt{'ED_CLEGED3'} |= "";
 	$$refOpt{'ED_CLEGED4'} |= "";
 }
@@ -428,10 +465,10 @@ sub EDMS_edidx_build (\%){
 
 sub EDMS_edidx_write (\%) {
 	my ($refOpt)	= shift;
-	my $cfg 	= config_read('EDOCMNGR');
+	my $cfg		= config_read('EDOCMNGR');
 	my @edms_cols 	= split(/,/, $cfg->{'EDMS_INDEX_COLS'});
 	my $index 	= $$refOpt{'ED_REFIDDOC'} . "_" . $$refOpt{'ED_IDLDOC'} .".idx";
-	
+
 	open (my $fh, ">>$index") or die "ERROR: can't open $index : $!";
 	my $csv = Text::CSV->new({ binary => 1, sep_char => ';', eol => "\n", quote_space => 0 });
 
@@ -439,7 +476,7 @@ sub EDMS_edidx_write (\%) {
 	foreach my $key (@edms_cols){
 		push (@fields, $$refOpt{$key});
 	}
-	
+
 	$csv->print($fh, \@fields);
 	 close($fh);
 }
